# stage-left

[![Run tests](https://github.com/chris48s/stage-left/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/chris48s/stage-left/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/chris48s/stage-left/branch/master/graph/badge.svg?token=XS70M8EPCT)](https://codecov.io/gh/chris48s/stage-left)
[![PyPI Version](https://img.shields.io/pypi/v/stage-left.svg)](https://pypi.org/project/stage-left/)
![License](https://img.shields.io/pypi/l/stage-left.svg)
![Python Compatibility](https://img.shields.io/badge/dynamic/json?query=info.requires_python&label=python&url=https%3A%2F%2Fpypi.org%2Fpypi%2Fstage-left%2Fjson)
![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)

[[x]it!](https://xit.jotaen.net/) is a plain-text file format for todos and check lists. Stage-left parses [x]it! documents into python data structures.

## 📚 [Documentation](https://chris48s.github.io/stage-left/)
* [Usage Examples](https://chris48s.github.io/stage-left/usage.html)
* [API Reference](https://chris48s.github.io/stage-left/reference.html)
